@@ -1,5 +1,4 @@
 collapse.visregList <- function(obj, labels, ...) {
-  fit <- res <- NULL
   if (missing(labels)) {
     l <- sapply(obj, function(v) v$meta$y)
     if (any(duplicated(l))) {
@@ -9,9 +8,13 @@ collapse.visregList <- function(obj, labels, ...) {
     }
   }
   if (length(labels) != length(obj)) stop("labels do not match list", call.=FALSE)
-  for (i in 1:length(obj)) {
-    fit <- rbind(fit, data.frame(obj[[i]]$fit, visregCollapse=labels[i]))
-    res <- rbind(res, data.frame(obj[[i]]$res, visregCollapse=labels[i]))
+  fit <- data.frame(obj[[1]]$fit, visregCollapse=labels[1])
+  res <- data.frame(obj[[1]]$res, visregCollapse=labels[1])
+  if (length(obj) >= 2) {
+    for (i in 2:length(obj)) {
+      fit <- merge(fit, data.frame(obj[[i]]$fit, visregCollapse=labels[i]), all.x=TRUE, all.y=TRUE)
+      res <- merge(res, data.frame(obj[[i]]$res, visregCollapse=labels[i]), all.x=TRUE, all.y=TRUE)
+    }
   }
   meta <- obj[[1]]$meta
   meta$by <- "visregCollapse"
