@@ -1,5 +1,4 @@
-se.mlm <- function(object, newdata)
-{
+se.mlm <- function(object, newdata) {
   coef <- coef(object)
   ny <- ncol(coef)
   effects <- object$effects
@@ -8,12 +7,12 @@ se.mlm <- function(object, newdata)
   ynames <- colnames(coef)
   if (is.null(ynames)) {
     lhs <- object$terms[[2L]]
-    if (mode(lhs) == "call" && lhs[[1L]] == "cbind") 
+    if (mode(lhs) == "call" && lhs[[1L]] == "cbind")
       ynames <- as.character(lhs)[-1L]
     else ynames <- paste0("Y", seq_len(ny))
   }
   ind <- ynames == ""
-  if (any(ind)) 
+  if (any(ind))
     ynames[ind] <- paste0("Y", seq_len(ny))[ind]
   value <- NULL
   cl <- oldClass(object)
