@@ -43,7 +43,7 @@ visregLatticePlot <- function(v, partial, band, rug, whitespace, strip.names, to
   lresids <- data.frame(r=y, x=x, by=b, pos=v$res$visregPos)
   plot.args <- list(x=formula(lframe$fit~lframe$xx | lframe$by), type="l", ylim=ylim, xlab=v$meta$x, ylab=ylab, lframe=lframe, lresids=lresids, partial=partial, band=band, rug=rug, xlim=xlim, strip=strip, top=top, fill.par=fill.par)
   if (length(new.args)) plot.args[names(new.args)] <- new.args
-  if (is.null(dev.list())) trellis.device()
+  if (is.null(dev.list())) lattice::trellis.device()
   opar <- lattice::trellis.par.get()
 
   # Plot
